.ProseMirror{padding:1rem 1.75rem;font-family:-apple-system,blinkmacsystemfont,Segoe UI,roboto,oxygen,ubuntu,cantarell,Open Sans,Helvetica Neue,sans-serif;outline:none!important;margin:0!important}.ProseMirror *{color:var(--body-fg)}.ProseMirror p{font-size:15px!important}.ProseMirror h1{margin:.67em 0!important;font-size:2em!important;font-weight:700!important;line-height:1.2!important;display:block!important}.ProseMirror h2{padding:0;margin:.83em 0!important;font-size:1.5em!important;font-weight:700!important;line-height:1.2!important;display:block!important}.ProseMirror h3{margin:1em 0!important;padding:0!important;font-size:1.17em!important;font-weight:700!important;line-height:1.2!important;display:block!important}.ProseMirror>*+*{margin-top:.75em!important}.ProseMirror p.is-editor-empty:first-child:before{content:attr(data-placeholder);float:left;color:#a8a8a8;pointer-events:none;height:0}.ProseMirror ul{list-style-type:disc!important}.ProseMirror ol:not([type]){list-style-type:decimal!important}.ProseMirror ol[type=a]{list-style-type:lower-alpha!important}.ProseMirror ol[type=A]{list-style-type:upper-alpha!important}.ProseMirror ol[type=i]{list-style-type:lower-roman!important}.ProseMirror ol[type=I]{list-style-type:upper-roman!important}.ProseMirror li{margin:0;padding:0;list-style:inherit!important}.ProseMirror ol,.ProseMirror ul{margin:.3em 0!important;padding-left:2.5em!important}.ProseMirror ol li,.ProseMirror ul li{margin:.1em 0!important;padding-left:0!important;display:list-item!important;position:relative!important}.ProseMirror ol li::marker{color:var(--body-fg)!important;font-size:15px!important}.ProseMirror ul li::marker{color:var(--body-fg)!important;font-size:15px!important}.ProseMirror ol ol,.ProseMirror ul ul,.ProseMirror ol ul,.ProseMirror ul ol{margin:.1em 0 .1em .5em!important}.ProseMirror h1,.ProseMirror h2,.ProseMirror h3,.ProseMirror h4,.ProseMirror h5,.ProseMirror h6{text-transform:none;color:var(--body-fg);padding:0;line-height:1.1;background:0 0!important;border:none!important}.ProseMirror pre{color:#fff!important;background:#0d0d0d!important;border-radius:.5rem!important;padding:.75rem 1rem!important;font-family:JetBrainsMono,monospace!important}.ProseMirror pre code{color:#fff!important;background:0 0!important;padding:0!important;font-size:.8rem!important}.ProseMirror img{max-width:100%;height:auto}.ProseMirror blockquote{border-left:2px solid rgba(13,13,13,.1);padding-left:1rem}.ProseMirror hr{border:none;border-top:2px solid rgba(13,13,13,.1);margin:2rem 0!important}.ProseMirror a{text-decoration:underline}.ProseMirror table{border-collapse:collapse;table-layout:fixed;width:100%;margin:0;overflow:hidden}.ProseMirror table td,.ProseMirror table th,.ProseMirror table[show_borders=false]:hover td,.ProseMirror table[show_borders=false]:hover th{vertical-align:top;box-sizing:border-box;border:2px solid #ced4da;min-width:1em;padding:3px 5px;position:relative}.ProseMirror table[show_borders=false] td,.ProseMirror table[show_borders=false] th{box-sizing:border-box;border:none}.ProseMirror table td>*,.ProseMirror table th>*{margin-bottom:0}.ProseMirror table th{text-align:left;background-color:#f1f3f5;font-weight:700}.ProseMirror tr{background-color:#fff!important}.ProseMirror table .selectedCell:after{z-index:2;content:"";pointer-events:none;background:rgba(200,200,255,.4);position:absolute;top:0;bottom:0;left:0;right:0}.ProseMirror table .column-resize-handle{pointer-events:none;background-color:#adf;width:4px;position:absolute;top:0;bottom:-2px;right:-2px}.ProseMirror label{max-width:auto;width:auto;min-width:0;display:inline}.tableWrapper{overflow-x:auto}.resize-cursor{cursor:col-resize}.ProseMirror [draggable][contenteditable=false]{-webkit-user-select:text;-moz-user-select:text;user-select:text}.ProseMirror-selectednode{outline:2px solid var(--_a,#8cf)}li.ProseMirror-selectednode{outline:none}li.ProseMirror-selectednode:after{content:"";pointer-events:none;border:2px solid #8cf;position:absolute;top:-2px;bottom:-2px;left:-32px;right:-2px}
/*# sourceMappingURL=overrides.css.map*/